@@ -69,6 +69,6 @@ def MonteCarlo(
         results[i] = data[:,-1]
     
     mean = np.mean(results,0)
-    stddev = np.mean(results,0)
+    stddev = np.std(results,0,ddof=1)
 
     return results, mean, stddev
\ No newline at end of file
