@@ -64,8 +64,8 @@ def two_pos_controller(model, var0, t, param, Tt, xlimit, ylimit, x_index = -1,
         # control the y value by two position controller.
         y = two_position(x_delay[i], y, xlimit, ylimit)
     
-    y_final[len(time)-1] = y_final[len(t)-2]
-    results[len(time)-1] = results[len(time)-2]
+    y_final[len(t)-1] = y_final[len(t)-2]
+    results[len(t)-1] = results[len(t)-2]
     
     if n != 1: 
         r = np.array(results)
